@@ -25,6 +25,7 @@ MainWindow::MainWindow(QWidget *parent) :
     exitprompt_(new ExitPrompt),
     pausedscreen_(new PausedScreen),
     gameoverscreen_(new GameOverScreen),
+    titlescreen_(new TitleScreen),
     mutebutton_(new Mutebutton),
     state_(RUNNING),
     score_(0),
@@ -61,6 +62,7 @@ MainWindow::MainWindow(QWidget *parent) :
     sfx_duckpoo_ = Mix_LoadWAV("/opt/thembloodyducks/duckpoo.wav");
     sfx_poohit_ = Mix_LoadWAV("/opt/thembloodyducks/poohit.wav");
     sfx_gameover_ = Mix_LoadWAV("/opt/thembloodyducks/gameover.wav");
+    sfx_title_ = Mix_LoadWAV("/opt/thembloodyducks/title.wav");
 
     // Accsensor
     acc_ = AccSensor::New();
@@ -75,39 +77,16 @@ MainWindow::MainWindow(QWidget *parent) :
     shotlimittimer_ = new QTimer(this);
     connect(shotlimittimer_, SIGNAL(timeout()), this, SLOT(onShotLimitTimer()));
 
-    // Add some stuff to scene
-    // - hero
-    view_->scene()->addItem(hero_);
-
-    // - energy bar
-    view_->scene()->addItem(energybar_);
-
-    // - score
-    view_->scene()->addItem(scr_ones_);
-    view_->scene()->addItem(scr_tens_);
-    view_->scene()->addItem(scr_hunds_);
-    scr_ones_->setPos(770,450);
-    scr_tens_->setPos(752,450);
-    scr_hunds_->setPos(734,450);
-//    scr_ones_->setY(450);
-//    scr_tens_->setY(450);
-//    scr_hunds_->setY(450);
-
     // Settings
     loadSettings();
 
-    mutebutton_->setPos(0,430);
-    //mutebutton_->setY(430);
-    mutebutton_->toggle(mute_);
-    view_->scene()->addItem(mutebutton_);
-
 //#ifdef Q_WS_MAEMO_5
     this->showFullScreen();
 //#endif
 
-    if ( !newgame() ) {
-        // error
-    }
+    firstgame();
+
+    showTitlescreen();
 
 }
 
@@ -120,6 +99,7 @@ MainWindow::~MainWindow()
     Mix_FreeChunk(sfx_gameover_);
     Mix_FreeChunk(sfx_poohit_);
     Mix_FreeChunk(sfx_shot_);
+    Mix_FreeChunk(sfx_title_);
     Mix_CloseAudio();
     SDL_Quit();
 
@@ -143,6 +123,34 @@ int MainWindow::randInt(int min, int max) {
     return qrand() % ((max + 1) - min) + min;
 }
 
+void MainWindow::showTitlescreen() {
+    changeState(TITLE);
+    if ( !mute_ ) {
+        Mix_PlayChannel(-1, sfx_title_, 0);
+    }
+    view_->scene()->addItem(titlescreen_);
+    titlescreen_->setPos(0,0);
+}
+
+void MainWindow::firstgame() {
+    // Add some stuff to scene
+    // - hero
+    view_->scene()->addItem(hero_);
+    // - energy bar
+    view_->scene()->addItem(energybar_);
+    // - score
+    view_->scene()->addItem(scr_ones_);
+    view_->scene()->addItem(scr_tens_);
+    view_->scene()->addItem(scr_hunds_);
+    scr_ones_->setPos(770,450);
+    scr_tens_->setPos(752,450);
+    scr_hunds_->setPos(734,450);
+    mutebutton_->setPos(0,430);
+    mutebutton_->toggle(mute_);
+    view_->scene()->addItem(mutebutton_);
+    //newgame();
+}
+
 bool MainWindow::newgame() {
 
     view_->bgLottery();
@@ -223,9 +231,12 @@ void MainWindow::onDashboardClick() {
 }
 
 void MainWindow::onResume() {
-    if ( state_ == GAMEOVER ) {
+    if ( state_ == GAMEOVER || state_ == TITLE ) {
         newgame();
     }
+//    else if ( state_ == TITLE ) {
+//        firstgame();
+//    }
     changeState(RUNNING);
 }
 
@@ -289,6 +300,11 @@ void MainWindow::changeState(Gamestate state) {
             else if ( state_ == EXITPROMPT ) {
                 view_->scene()->removeItem(exitprompt_);
             }
+            else if ( state_ == TITLE ) {
+                view_->scene()->removeItem(titlescreen_);
+                //firstgame();
+                //return;
+            }
             else if ( state_ == GAMEOVER ) {
                 view_->scene()->removeItem(gameoverscreen_);
                 view_->scene()->removeItem(goscr_ones_);
