@@ -29,12 +29,15 @@ public slots:
 protected:
     void mousePressEvent(QMouseEvent * event);
     void keyPressEvent(QKeyEvent *event);
+    void keyReleaseEvent(QKeyEvent *event);
 
 private:
     QGraphicsScene *scene_;
     QPixmap bgpix_;
     QBrush *bgbrush_;
 
+    bool keyUDown_;
+
     Gamestate state_;
 };
 
